==> fop-0.93-src.tar.gz: fop-0.93/src/java/org/apache/fop/pdf/ASCII85Filter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: ASCII85Filter.java 426576 2006-07-28 15:44:37Z jeremias $ */
 
package org.apache.fop.pdf;

import java.io.OutputStream;
import java.io.IOException;

import org.apache.xmlgraphics.util.io.ASCII85OutputStream;

/**
 * PDF Filter for ASCII85.
 * This applies a filter to a pdf stream that converts
 * the data to ASCII.
 */
public class ASCII85Filter extends PDFFilter {

    /**
     * Get the PDF name of this filter.
     *
     * @return the name of the filter to be inserted into the PDF
     */
    public String getName() {
        return "/ASCII85Decode";
    }

    /**
     * @see org.apache.fop.pdf.PDFFilter#isASCIIFilter()
     */
    public boolean isASCIIFilter() {
        return true;
    }
    
    /**
     * Get the decode parameters.
     *
     * @return always null
     */
    public String getDecodeParms() {
        return null;
    }

    /**
     * @see org.apache.fop.pdf.PDFFilter#applyFilter(OutputStream)
     */
    public OutputStream applyFilter(OutputStream out) throws IOException {
        return new ASCII85OutputStream(out);
    }

}

==> fop-1.0-src.tar.gz: fop-1.0/src/java/org/apache/fop/pdf/ASCII85Filter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: ASCII85Filter.java 679326 2008-07-24 09:35:34Z vhennebert $ */

package org.apache.fop.pdf;

import java.io.OutputStream;
import java.io.IOException;

import org.apache.xmlgraphics.util.io.ASCII85OutputStream;

/**
 * PDF Filter for ASCII85.
 * This applies a filter to a pdf stream that converts
 * the data to ASCII.
 */
public class ASCII85Filter extends PDFFilter {

    /**
     * Get the PDF name of this filter.
     *
     * @return the name of the filter to be inserted into the PDF
     */
    public String getName() {
        return "/ASCII85Decode";
    }

    /**
     * {@inheritDoc}
     */
    public boolean isASCIIFilter() {
        return true;
    }

    /**
     * Get the decode parameters.
     *
     * @return always null
     */
    public PDFObject getDecodeParms() {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    public OutputStream applyFilter(OutputStream out) throws IOException {
        if (isApplied()) {
            return out;
        } else {
            return new ASCII85OutputStream(out);
        }
    }

}
